@@ -47,7 +47,7 @@ from flake8_dunder_all.utils import get_docstring_lineno, mark_text_ranges
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT"
-__version__: str = "0.2.0"
+__version__: str = "0.2.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["Visitor", "Plugin", "check_and_add_all", "DALL000"]
@@ -250,9 +250,10 @@ def check_and_add_all(filename: PathLike, quote_type: str = '"') -> int:
 		for line in source.splitlines():
 			noqas = find_noqa(line)
 			if noqas is not None:
-				noqa_list: List[str] = noqas.group(1).rstrip().upper().split(',')
-				if "DALL000" in noqa_list:
-					return 0
+				if noqas["codes"]:
+					noqa_list: List[str] = noqas["codes"].rstrip().upper().split(',')
+					if "DALL000" in noqa_list:
+						return 0
 
 		tree = ast.parse(source)
 		if sys.version_info < (3, 8):  # pragma: no cover (py38+)
